PoolClient

Struct PoolClient 

pub struct PoolClient<H> { /* private fields */ }
A synchronous stratum pool client, customized with a MessageHandler.

Implementations

Source

impl<H: MessageHandler> PoolClient<H>

pub fn connect<F>( address: &str, login: &str, pass: &str, keepalive: Option<Duration>, agent: &str, make_handler: F, ) -> Result<Self>
where F: FnOnce(Job) -> H,

Synchronously connect to the server; pass the initial job to a MessageHandler constructor.

pub fn write_handle(&self) -> Arc<Mutex<PoolClientWriter>>

Return a new handle to the write end of the client connection.

pub fn handler(&self) -> &H

Borrow the message handler that was created in connect().

pub fn run(self) -> Result<()>

Handle messages until the connection is closed.