pub struct PoolClient<H> { /* private fields */ }Expand description
A synchronous stratum pool client, customized with a MessageHandler.
Implementations
Sourceimpl<H: MessageHandler> PoolClient<H>
impl<H: MessageHandler> PoolClient<H>
Sourcepub fn connect<F>(
address: &str,
login: &str,
pass: &str,
keepalive: Option<Duration>,
agent: &str,
make_handler: F,
) -> Result<Self>
pub fn connect<F>( address: &str, login: &str, pass: &str, keepalive: Option<Duration>, agent: &str, make_handler: F, ) -> Result<Self>
Synchronously connect to the server; pass the initial job to a MessageHandler constructor.
Sourcepub fn write_handle(&self) -> Arc<Mutex<PoolClientWriter>>
pub fn write_handle(&self) -> Arc<Mutex<PoolClientWriter>>
Return a new handle to the write end of the client connection.